@@ -123,15 +123,33 @@ where
         emit!(self, n.block);
     }
 
+    #[emitter]
+    fn emit_keyframes_name(&mut self, n: &KeyframesName) -> Result {
+        match n {
+            KeyframesName::Ident(n) => emit!(self, n),
+            KeyframesName::Str(n) => emit!(self, n),
+        }
+    }
+
     #[emitter]
     fn emit_keyframes_rule(&mut self, n: &KeyframesRule) -> Result {
         punct!(self, "@");
         keyword!(self, "keyframes");
         space!(self);
 
-        emit!(self, n.id);
-        if !n.id.value.is_empty() {
-            space!(self);
+        emit!(self, n.name);
+
+        match &n.name {
+            KeyframesName::Ident(n) => {
+                if !n.value.is_empty() {
+                    space!(self);
+                }
+            }
+            KeyframesName::Str(n) => {
+                if !n.value.is_empty() {
+                    space!(self);
+                }
+            }
         }
 
         punct!(self, "{");
@@ -333,16 +351,27 @@ where
     fn emit_declaration(&mut self, n: &Declaration) -> Result {
         emit!(self, n.property);
         punct!(self, ":");
-        formatting_space!(self);
 
-        self.emit_list(
-            &n.value,
-            ListFormat::SpaceDelimited | ListFormat::SingleLine,
-        )?;
+        let is_custom_property = n.property.value.starts_with("--");
+
+        if !is_custom_property {
+            formatting_space!(self);
+        }
+
+        let format = match is_custom_property {
+            true => ListFormat::NotDelimited,
+            false => ListFormat::SpaceDelimited | ListFormat::SingleLine,
+        };
+
+        self.emit_list(&n.value, format)?;
 
         if let Some(tok) = n.important {
-            formatting_space!(self);
+            if !is_custom_property {
+                formatting_space!(self);
+            }
+
             punct!(self, tok, "!");
+
             self.wr.write_raw(Some(tok), "important")?;
         }
 
