@@ -18,11 +18,11 @@ macro_rules! punct {
 
 macro_rules! keyword {
     ($g:expr,$span:expr,$n:expr) => {{
-        $g.wr.write_ident(Some($span), $n, false)?;
+        $g.wr.write_raw(Some($span), $n)?;
     }};
 
     ($g:expr,$n:expr) => {{
-        $g.wr.write_ident(None, $n, false)?;
+        $g.wr.write_raw(None, $n)?;
     }};
 }
 
